When DC mapping changes reselect current pen to update physical
width.

diff --git a/dlls/gdi/dc.c b/dlls/gdi/dc.c
index 43e5845..3cd121a 100644
--- a/dlls/gdi/dc.c
+++ b/dlls/gdi/dc.c
@@ -262,10 +262,13 @@
     dc->vport2WorldValid = DC_InvertXform( &dc->xformWorld2Vport,
         &dc->xformVport2World );
 
     /* Reselect the font back into the dc so that the font size
        gets updated. */
     if(memcmp(&oldworld2vport, &dc->xformWorld2Vport, sizeof(oldworld2vport)))
+    {
         SelectObject(dc->hSelf, GetCurrentObject(dc->hSelf, OBJ_FONT));
+        SelectObject(dc->hSelf, GetCurrentObject(dc->hSelf, OBJ_PEN));
+    }
 }
@@ -262,10 +262,13 @@
         &dc->xformVport2World );
 
-    /* Reselect the font back into the dc so that the font size
+    /* Reselect the font and pen back into the dc so that the size
        gets updated. */
     if(memcmp(&oldworld2vport, &dc->xformWorld2Vport, sizeof(oldworld2vport)))